@@ -1,7 +1,6 @@
 #ifndef INCLUDE_RUBY_CONFIG_H
 #define INCLUDE_RUBY_CONFIG_H 1
 /* confdefs.h */
-#define CANONICALIZATION_FOR_MATHN 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
@@ -17,10 +16,9 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
-#define HAVE_INFINITY 1
-#define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
+#define HAVE_STMT_AND_DECL_IN_EXPR 1
 #define BROKEN_CRYPT 1
 #define HAVE_CRT_EXTERNS_H 1
 #define HAVE_LIBDL 1
@@ -36,6 +34,8 @@
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_MALLOC_H 1
 #define HAVE_PWD_H 1
+#define HAVE_SANITIZER_MSAN_INTERFACE_H 1
+#define HAVE_STDALIGN_H 1
 #define HAVE_SYS_ATTR_H 1
 #define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_FILE_H 1
@@ -68,41 +68,49 @@
 #define SIZEOF_CLOCK_T 8
 #define PACKED_STRUCT(x) x __attribute__((packed))
 #define PRI_LL_PREFIX "ll"
+#define HAVE_PID_T 1
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
 #define PIDT2NUM(v) INT2NUM(v)
 #define NUM2PIDT(v) NUM2INT(v)
 #define PRI_PIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_UID_T 1
 #define rb_uid_t uid_t
 #define SIGNEDNESS_OF_UID_T +1
 #define UIDT2NUM(v) UINT2NUM(v)
 #define NUM2UIDT(v) NUM2UINT(v)
 #define PRI_UIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_GID_T 1
 #define rb_gid_t gid_t
 #define SIGNEDNESS_OF_GID_T +1
 #define GIDT2NUM(v) UINT2NUM(v)
 #define NUM2GIDT(v) NUM2UINT(v)
 #define PRI_GIDT_PREFIX PRI_INT_PREFIX
+#define HAVE_TIME_T 1
 #define rb_time_t time_t
 #define SIGNEDNESS_OF_TIME_T -1
 #define TIMET2NUM(v) LONG2NUM(v)
 #define NUM2TIMET(v) NUM2LONG(v)
 #define PRI_TIMET_PREFIX PRI_LONG_PREFIX
+#define HAVE_DEV_T 1
 #define rb_dev_t dev_t
 #define SIGNEDNESS_OF_DEV_T -1
 #define DEVT2NUM(v) INT2NUM(v)
 #define NUM2DEVT(v) NUM2INT(v)
 #define PRI_DEVT_PREFIX PRI_INT_PREFIX
+#define HAVE_MODE_T 1
 #define rb_mode_t mode_t
 #define SIGNEDNESS_OF_MODE_T +1
-#define MODET2NUM(v) UINT2NUM(v)
-#define NUM2MODET(v) NUM2UINT(v)
-#define PRI_MODET_PREFIX PRI_INT_PREFIX
+#define MODET2NUM(v) USHORT2NUM(v)
+#define NUM2MODET(v) NUM2USHORT(v)
+#define PRI_MODET_PREFIX PRI_SHORT_PREFIX
+#define HAVE_RLIM_T 1
 #define rb_rlim_t rlim_t
 #define SIGNEDNESS_OF_RLIM_T +1
 #define RLIM2NUM(v) ULL2NUM(v)
 #define NUM2RLIM(v) NUM2ULL(v)
 #define PRI_RLIM_PREFIX PRI_LL_PREFIX
+#define HAVE_OFF_T 1
 #define rb_off_t off_t
 #define SIGNEDNESS_OF_OFF_T -1
 #define OFFT2NUM(v) LL2NUM(v)
@@ -118,6 +126,8 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
+#define RUBY_ALIGNAS(x) __attribute__((__aligned__(x)))
+#define RUBY_ALIGNOF alignof
 #define CONSTFUNC(x) __attribute__ ((__const__)) x
 #define PUREFUNC(x) __attribute__ ((__pure__)) x
 #define NORETURN(x) __attribute__ ((__noreturn__)) x
@@ -126,6 +136,8 @@
 #define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
 #define NOINLINE(x) __attribute__ ((__noinline__)) x
 #define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
+#define NO_SANITIZE_ADDRESS(x) __attribute__ ((__no_sanitize_address__)) x
+#define NO_ADDRESS_SAFETY_ANALYSIS(x) __attribute__ ((__no_address_safety_analysis__)) x
 #define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
 #define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
 #define WEAK(x) __attribute__ ((__weak__)) x
@@ -206,6 +218,7 @@
 #define HAVE_ISNAN 1
 #define HAVE_LGAMMA_R 1
 #define HAVE_MEMMOVE 1
+#define HAVE_NAN 1
 #define HAVE_NEXTAFTER 1
 #define HAVE_STRCHR 1
 #define HAVE_STRERROR 1
@@ -242,14 +255,20 @@
 #define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
+#define HAVE_GETLOGIN 1
+#define HAVE_GETLOGIN_R 1
 #define HAVE_GETPGID 1
 #define HAVE_GETPGRP 1
 #define HAVE_GETPRIORITY 1
+#define HAVE_GETPWNAM 1
 #define HAVE_GETPWNAM_R 1
+#define HAVE_GETPWUID 1
+#define HAVE_GETPWUID_R 1
 #define HAVE_GETRLIMIT 1
 #define HAVE_GETSID 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GMTIME_R 1
+#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_ISSETUGID 1
@@ -322,6 +341,7 @@
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_BUILTIN___BUILTIN_TRAP 1
 #define HAVE_BSD_QSORT_R 1
 #define ATAN2_INF_C99 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
@@ -334,21 +354,21 @@
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
+#define FIBER_USE_COROUTINE "coroutine/amd64/Context.h"
 #define _REENTRANT 1
 #define _THREAD_SAFE 1
 #define HAVE_LIBPTHREAD 1
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
-#define HAVE_PTHREAD_ATTR_INIT 1
+#define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
 #define HAVE_PTHREAD_GET_STACKADDR_NP 1
 #define HAVE_PTHREAD_GET_STACKSIZE_NP 1
-#define HAVE_PTHREAD_COND_INIT 1
-#define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SETNAME_NP 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(name)
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
+#define HAVE_MACH_O_LOADER_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_LIBUNWIND_H 1
 #define HAVE_BACKTRACE 1
@@ -358,9 +378,10 @@
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
 #define HAVE_SIGSETJMP 1
-#define RUBY_SETJMP(env) _setjmp((env))
-#define RUBY_LONGJMP(env,val) _longjmp((env),val)
-#define RUBY_JMP_BUF jmp_buf
+#define RUBY_SETJMP(env) sigsetjmp((env),0)
+#define RUBY_LONGJMP(env,val) siglongjmp((env),val)
+#define RUBY_JMP_BUF sigjmp_buf
+#define USE_MJIT 1
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "x86_64-darwin12.0"
 #endif /* INCLUDE_RUBY_CONFIG_H */
